# YapHue
> Yet Another Python / Philips Hue -library

## Instructions

None as of yet, this is just a small hobby project, as I wanted to know how the
Hue actually works. The other libraries available for Hue are more mature and
most likely a lot nicer to use...

The library itself is functional, although lacking a lot of functionality and the
API is bound to change, as I gain more experience in actually using it...
